{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">ROA Prefices)</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Prefix</th>
              <td><a href="{{ object.pk.get_absolute_url }}">{{ object.prefix }}</a></td>
            </tr>
            <tr>
              <th scope="row">Maximum Prefix Length</th>
              <td>{{ object.max_length }}</td>
            </tr>
            <tr>
              <th scope="row">ROA Name</th>
              <td><a href="{{ object.roa_name.get_absolute_url }}">{{ object.roa_name }}</a></td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/comments.html' %}
    </div>
  </div>
  </div>
{% endblock content %}
